# Generated by Django 4.2.6 on 2024-06-07 07:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscarbot', '0007_alter_user_name_alter_user_username'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='last_path',
            field=models.CharField(blank=True, default='/start', max_length=250, null=True),
        ),
        migrations.AddField(
            model_name='user',
            name='path',
            field=models.CharField(blank=True, max_length=250, null=True),
        ),
    ]
