# Generated by Django 4.2.6 on 2024-06-05 06:21

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('oscarbot', '0006_user_state_information'),
    ]

    operations = [
        migrations.AlterField(
            model_name='user',
            name='name',
            field=models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Имя'),
        ),
        migrations.AlterField(
            model_name='user',
            name='username',
            field=models.CharField(blank=True, default='', max_length=200, null=True, verbose_name='Username'),
        ),
    ]
